==> nextcloud-14.0.13.zip: nextcloud/lib/l10n/en_GB.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Cannot write into \"config\" directory!",
    "This can usually be fixed by giving the webserver write access to the config directory" : "This can usually be fixed by giving the webserver write access to the config directory",
    "See %s" : "See %s",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "This can usually be fixed by giving the webserver write access to the config directory. See %s",
    "Sample configuration detected" : "Sample configuration detected",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php",
    "%1$s and %2$s" : "%1$s and %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s and %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s and %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s and %5$s",
    "Education Edition" : "Education Edition",
    "Enterprise bundle" : "Enterprise bundle",
    "Groupware bundle" : "Groupware bundle",
    "Social sharing bundle" : "Social sharing bundle",
    "PHP %s or higher is required." : "PHP %s or higher is required.",
    "PHP with a version lower than %s is required." : "PHP with a version lower than %s is required.",
    "%sbit or higher PHP required." : "%sbit or higher PHP required.",
    "Following databases are supported: %s" : "Following databases are supported: %s",
    "The command line tool %s could not be found" : "The command line tool %s could not be found",
    "The library %s is not available." : "The library %s is not available.",
    "Following platforms are supported: %s" : "Following platforms are supported: %s",
    "Server version %s or higher is required." : "Server version %s or higher is required.",
    "Server version %s or lower is required." : "Server version %s or lower is required.",
    "Logged in user must be an admin" : "Logged in user must be an admin",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "Avatar image is not square" : "Avatar image is not square",
    "today" : "today",
    "tomorrow" : "tomorrow",
    "yesterday" : "yesterday",
    "_in %n day_::_in %n days_" : ["in %n day","in %n days"],
    "_%n day ago_::_%n days ago_" : ["%n day ago","%n days ago"],
    "next month" : "next month",
    "last month" : "last month",
    "_in %n month_::_in %n months_" : ["in %n month","in %n months"],
    "_%n month ago_::_%n months ago_" : ["%n month ago","%n months ago"],
    "next year" : "next year",
    "last year" : "last year",
    "_in %n year_::_in %n years_" : ["in %n year","in %n years"],
    "_%n year ago_::_%n years ago_" : ["%n year ago","%n years ago"],
    "_in %n hour_::_in %n hours_" : ["in %n hour","in %n hours"],
    "_%n hour ago_::_%n hours ago_" : ["%n hour ago","%n hours ago"],
    "_in %n minute_::_in %n minutes_" : ["in %n minute","in %n minutes"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute ago","%n minutes ago"],
    "in a few seconds" : "in a few seconds",
    "seconds ago" : "seconds ago",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator.",
    "File name is a reserved word" : "File name is a reserved word",
    "File name contains at least one invalid character" : "File name contains at least one invalid character",
    "File name is too long" : "File name is too long",
    "Dot files are not allowed" : "Dot files are not allowed",
    "Empty filename is not allowed" : "Empty filename is not allowed",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" cannot be installed because appinfo file cannot be read.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "App \"%s\" cannot be installed. It is not compatible with this version of the server.",
    "__language_name__" : "English (British English)",
    "This is an automatically sent email, please do not reply." : "This is an automatically sent email, please do not reply.",
    "Help" : "Help",
    "Apps" : "Apps",
    "Settings" : "Settings",
    "Log out" : "Log out",
    "Users" : "Users",
    "Unknown user" : "Unknown user",
    "Overview" : "Overview",
    "Basic settings" : "Basic settings",
    "Sharing" : "Sharing",
    "Security" : "Security",
    "Additional settings" : "Additional settings",
    "Personal info" : "Personal info",
    "Mobile & desktop" : "Mobile & desktop",
    "%s enter the database username and name." : "%s enter the database username and name.",
    "%s enter the database username." : "%s enter the database username.",
    "%s enter the database name." : "%s enter the database name.",
    "%s you may not use dots in the database name" : "%s you may not use dots in the database name",
    "Oracle connection could not be established" : "Oracle connection could not be established",
    "Oracle username and/or password not valid" : "Oracle username and/or password not valid",
    "PostgreSQL username and/or password not valid" : "PostgreSQL username and/or password not valid",
    "You need to enter details of an existing account." : "You need to enter details of an existing account.",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! ",
    "For the best results, please consider using a GNU/Linux server instead." : "For the best results, please consider using a GNU/Linux server instead.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir setting has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP.",
    "Set an admin username." : "Set an admin username.",
    "Set an admin password." : "Set an admin password.",
    "Can't create or write into the data directory %s" : "Can't create or write into the data directory %s",
    "Invalid Federated Cloud ID" : "Invalid Federated Cloud ID",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Sharing backend %s must implement the interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Sharing backend %s not found",
    "Sharing backend for %s not found" : "Sharing backend for %s not found",
    "Open »%s«" : "Open »%s«",
    "You are not allowed to share %s" : "You are not allowed to share %s",
    "Can’t increase permissions of %s" : "Can’t increase permissions of %s",
    "Files can’t be shared with delete permissions" : "Files can’t be shared with delete permissions",
    "Files can’t be shared with create permissions" : "Files can’t be shared with create permissions",
    "Expiration date is in the past" : "Expiration date is in the past",
    "Can’t set expiration date more than %s days in the future" : "Can’t set expiration date more than %s days in the future",
    "Click the button below to open it." : "Click the button below to open it.",
    "The requested share does not exist anymore" : "The requested share does not exist anymore",
    "Could not find category \"%s\"" : "Could not find category \"%s\"",
    "Sunday" : "Sunday",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Sun." : "Sun.",
    "Mon." : "Mon.",
    "Tue." : "Tue.",
    "Wed." : "Wed.",
    "Thu." : "Thu.",
    "Fri." : "Fri.",
    "Sat." : "Sat.",
    "Su" : "Su",
    "Mo" : "Mo",
    "Tu" : "Tu",
    "We" : "We",
    "Th" : "Th",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "January",
    "February" : "February",
    "March" : "March",
    "April" : "April",
    "May" : "May",
    "June" : "June",
    "July" : "July",
    "August" : "August",
    "September" : "September",
    "October" : "October",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "A valid username must be provided",
    "Username contains whitespace at the beginning or at the end" : "Username contains whitespace at the beginning or at the end",
    "Username must not consist of dots only" : "Username must not consist of dots only",
    "A valid password must be provided" : "A valid password must be provided",
    "The username is already being used" : "The username is already being used",
    "Could not create user" : "Could not create user",
    "User disabled" : "User disabled",
    "Login canceled by app" : "Login cancelled by app",
    "a safe home for all your data" : "a safe home for all your data",
    "File is currently busy, please try again later" : "File is currently busy, please try again later",
    "Can't read file" : "Can't read file",
    "Application is not enabled" : "Application is not enabled",
    "Authentication error" : "Authentication error",
    "Token expired. Please reload page." : "Token expired. Please reload page.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No database drivers (sqlite, mysql, or postgresql) installed.",
    "Cannot write into \"config\" directory" : "Cannot write into \"config\" directory",
    "Cannot write into \"apps\" directory" : "Cannot write into \"apps\" directory",
    "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s" : "This can usually be fixed by giving the webserver write access to the apps directory or disabling the appstore in the config file. See %s",
    "Cannot create \"data\" directory" : "Cannot create \"data\" directory",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "This can usually be fixed by giving the webserver write access to the root directory. See %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s.",
    "Setting locale to %s failed" : "Setting locale to %s failed",
    "Please install one of these locales on your system and restart your webserver." : "Please install one of these locales on your system and restart your webserver.",
    "Please ask your server administrator to install the module." : "Please ask your server administrator to install the module.",
    "PHP module %s not installed." : "PHP module %s not installed.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP setting \"%s\" is not set to \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Adjusting this setting in php.ini will allow Nextcloud to run",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 is at least required. Currently %s is installed.",
    "To fix this issue update your libxml2 version and restart your web server." : "To fix this issue update your libxml2 version and restart your web server.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modules have been installed, but they are still listed as missing?",
    "Please ask your server administrator to restart the web server." : "Please ask your server administrator to restart the web server.",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 required",
    "Please upgrade your database version" : "Please upgrade your database version",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Please change the permissions to 0770 so that the directory cannot be listed by other users.",
    "Your data directory is readable by other users" : "Your data directory is readable by other users",
    "Your data directory must be an absolute path" : "Your data directory must be an absolute path",
    "Check the value of \"datadirectory\" in your configuration" : "Check the value of \"datadirectory\" in your configuration",
    "Your data directory is invalid" : "Your data directory is invalid",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ensure there is a file called \".ocdata\" in the root of the data directory.",
    "Could not obtain lock type %d on \"%s\"." : "Could not obtain lock type %d on \"%s\".",
    "Storage unauthorized. %s" : "Storage unauthorised. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Storage connection error. %s",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Storage connection timeout. %s" : "Storage connection timeout. %s",
    "Library %s with a version higher than %s is required - available version %s." : "Library %s with a version higher than %s is required - available version %s.",
    "Library %s with a version lower than %s is required - available version %s." : "Library %s with a version lower than %s is required - available version %s.",
    "Create" : "Create",
    "Change" : "Change",
    "Delete" : "Delete",
    "Share" : "Share",
    "Unlimited" : "Unlimited",
    "Verifying" : "Verifying",
    "Verifying …" : "Verifying …",
    "Verify" : "Verify",
    "Sharing %s failed, because the backend does not allow shares from type %i" : "Sharing %s failed, because the backend does not allow shares from type %i",
    "Sharing %s failed, because the file does not exist" : "Sharing %s failed, because the file does not exist",
    "Sharing %s failed, because you can not share with yourself" : "Sharing %s failed, because you can not share with yourself",
    "Sharing %s failed, because the user %s does not exist" : "Sharing %s failed, because the user %s does not exist",
    "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of",
    "Sharing %s failed, because this item is already shared with %s" : "Sharing %s failed, because this item is already shared with %s",
    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
    "Sharing %s failed, because the group %s does not exist" : "Sharing %s failed, because the group %s does not exist",
    "Sharing %s failed, because %s is not a member of the group %s" : "Sharing %s failed, because %s is not a member of the group %s",
    "You need to provide a password to create a public link, only protected links are allowed" : "You need to provide a password to create a public link, only protected links are allowed",
    "Sharing %s failed, because sharing with links is not allowed" : "Sharing %s failed, because sharing with links is not allowed",
    "Not allowed to create a federated share with the same user" : "Not allowed to create a federated share with the same user",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Sharing %s failed, could not find %s, maybe the server is currently unreachable.",
    "Share type %s is not valid for %s" : "Share type %s is not valid for %s",
    "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Cannot set expiry date. Shares cannot expire later than %s after they have been shared",
    "Cannot set expiration date. Expiration date is in the past" : "Cannot set expiry date. Expiry date is in the past",
    "Sharing failed, because the user %s is the original sharer" : "Sharing failed, because the user %s is the original sharer",
    "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Sharing %s failed, because the permissions exceed permissions granted to %s",
    "Sharing %s failed, because resharing is not allowed" : "Sharing %s failed, because resharing is not allowed",
    "Sharing %s failed, because the sharing backend for %s could not find its source" : "Sharing %s failed, because the sharing backend for %s could not find its source",
    "Sharing %s failed, because the file could not be found in the file cache" : "Sharing %s failed, because the file could not be found in the file cache",
    "%s shared »%s« with you" : "%s shared \"%s\" with you",
    "%s shared »%s« with you." : "%s shared »%s« with you.",
    "%s via %s" : "%s via %s",
    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.0rc3.zip: nextcloud/lib/l10n/en_GB.js <==
OC.L10N.register(
    "lib",
    {
    "Cannot write into \"config\" directory!" : "Cannot write into \"config\" directory!",
    "See %s" : "See %s",
    "Sample configuration detected" : "Sample configuration detected",
    "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php",
    "%1$s and %2$s" : "%1$s and %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s and %3$s",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s and %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s and %5$s",
    "Education Edition" : "Education Edition",
    "Enterprise bundle" : "Enterprise bundle",
    "Groupware bundle" : "Groupware bundle",
    "Social sharing bundle" : "Social sharing bundle",
    "PHP %s or higher is required." : "PHP %s or higher is required.",
    "PHP with a version lower than %s is required." : "PHP with a version lower than %s is required.",
    "%sbit or higher PHP required." : "%sbit or higher PHP required.",
    "The command line tool %s could not be found" : "The command line tool %s could not be found",
    "The library %s is not available." : "The library %s is not available.",
    "Server version %s or higher is required." : "Server version %s or higher is required.",
    "Server version %s or lower is required." : "Server version %s or lower is required.",
    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Logged in user must be an admin, a sub-admin or has special right to access this setting",
    "Logged in user must be an admin" : "Logged in user must be an admin",
    "Authentication" : "Authentication",
    "Unknown filetype" : "Unknown filetype",
    "Invalid image" : "Invalid image",
    "Avatar image is not square" : "Avatar image is not square",
    "today" : "today",
    "tomorrow" : "tomorrow",
    "yesterday" : "yesterday",
    "_in %n day_::_in %n days_" : ["in %n day","in %n days"],
    "_%n day ago_::_%n days ago_" : ["%n day ago","%n days ago"],
    "next month" : "next month",
    "last month" : "last month",
    "_in %n month_::_in %n months_" : ["in %n month","in %n months"],
    "_%n month ago_::_%n months ago_" : ["%n month ago","%n months ago"],
    "next year" : "next year",
    "last year" : "last year",
    "_in %n year_::_in %n years_" : ["in %n year","in %n years"],
    "_%n year ago_::_%n years ago_" : ["%n year ago","%n years ago"],
    "_in %n hour_::_in %n hours_" : ["in %n hour","in %n hours"],
    "_%n hour ago_::_%n hours ago_" : ["%n hour ago","%n hours ago"],
    "_in %n minute_::_in %n minutes_" : ["in %n minute","in %n minutes"],
    "_%n minute ago_::_%n minutes ago_" : ["%n minute ago","%n minutes ago"],
    "in a few seconds" : "in a few seconds",
    "seconds ago" : "seconds ago",
    "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Module with ID: %s does not exist. Please enable it in your apps settings or contact your administrator.",
    "File already exists" : "File already exists",
    "File name is a reserved word" : "File name is a reserved word",
    "File name contains at least one invalid character" : "File name contains at least one invalid character",
    "File name is too long" : "File name is too long",
    "Dot files are not allowed" : "Dot files are not allowed",
    "Empty filename is not allowed" : "Empty filename is not allowed",
    "App \"%s\" cannot be installed because appinfo file cannot be read." : "App \"%s\" cannot be installed because appinfo file cannot be read.",
    "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "App \"%s\" cannot be installed. It is not compatible with this version of the server.",
    "__language_name__" : "English (British English)",
    "This is an automatically sent email, please do not reply." : "This is an automatically sent email, please do not reply.",
    "Help" : "Help",
    "Apps" : "Apps",
    "Settings" : "Settings",
    "Log out" : "Log out",
    "Users" : "Users",
    "Email" : "Email",
    "Phone" : "Phone",
    "Twitter" : "Twitter",
    "Website" : "Website",
    "Address" : "Address",
    "Profile picture" : "Profile picture",
    "About" : "About",
    "Full name" : "Full name",
    "Unknown user" : "Unknown user",
    "Additional settings" : "Additional settings",
    "You need to enter details of an existing account." : "You need to enter details of an existing account.",
    "Oracle connection could not be established" : "Oracle connection could not be established",
    "Oracle username and/or password not valid" : "Oracle username and/or password not valid",
    "PostgreSQL username and/or password not valid" : "PostgreSQL username and/or password not valid",
    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! ",
    "For the best results, please consider using a GNU/Linux server instead." : "For the best results, please consider using a GNU/Linux server instead.",
    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir setting has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged.",
    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP.",
    "Set an admin username." : "Set an admin username.",
    "Set an admin password." : "Set an admin password.",
    "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Sharing backend %s must implement the interface OCP\\Share_Backend",
    "Sharing backend %s not found" : "Sharing backend %s not found",
    "Sharing backend for %s not found" : "Sharing backend for %s not found",
    "Open »%s«" : "Open »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "You are not allowed to share %s" : "You are not allowed to share %s",
    "Cannot increase permissions of %s" : "Cannot increase permissions of %s",
    "Expiration date is in the past" : "Expiration date is in the past",
    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
    "Click the button below to open it." : "Click the button below to open it.",
    "The requested share does not exist anymore" : "The requested share does not exist any more",
    "Could not find category \"%s\"" : "Could not find category \"%s\"",
    "Sunday" : "Sunday",
    "Monday" : "Monday",
    "Tuesday" : "Tuesday",
    "Wednesday" : "Wednesday",
    "Thursday" : "Thursday",
    "Friday" : "Friday",
    "Saturday" : "Saturday",
    "Sun." : "Sun.",
    "Mon." : "Mon.",
    "Tue." : "Tue.",
    "Wed." : "Wed.",
    "Thu." : "Thu.",
    "Fri." : "Fri.",
    "Sat." : "Sat.",
    "Su" : "Su",
    "Mo" : "Mo",
    "Tu" : "Tu",
    "We" : "We",
    "Th" : "Th",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "January",
    "February" : "February",
    "March" : "March",
    "April" : "April",
    "May" : "May",
    "June" : "June",
    "July" : "July",
    "August" : "August",
    "September" : "September",
    "October" : "October",
    "November" : "November",
    "December" : "December",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mar.",
    "Apr." : "Apr.",
    "May." : "May.",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Oct.",
    "Nov." : "Nov.",
    "Dec." : "Dec.",
    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
    "A valid username must be provided" : "A valid username must be provided",
    "Username contains whitespace at the beginning or at the end" : "Username contains whitespace at the beginning or at the end",
    "Username must not consist of dots only" : "Username must not consist of dots only",
    "A valid password must be provided" : "A valid password must be provided",
    "The username is already being used" : "The username is already being used",
    "Could not create user" : "Could not create user",
    "User disabled" : "User disabled",
    "Login canceled by app" : "Login cancelled by app",
    "a safe home for all your data" : "a safe home for all your data",
    "File is currently busy, please try again later" : "File is currently busy, please try again later",
    "Application is not enabled" : "Application is not enabled",
    "Authentication error" : "Authentication error",
    "Token expired. Please reload page." : "Token expired. Please reload page.",
    "No database drivers (sqlite, mysql, or postgresql) installed." : "No database drivers (sqlite, mysql, or postgresql) installed.",
    "PHP module %s not installed." : "PHP module %s not installed.",
    "Please ask your server administrator to install the module." : "Please ask your server administrator to install the module.",
    "PHP setting \"%s\" is not set to \"%s\"." : "PHP setting \"%s\" is not set to \"%s\".",
    "Adjusting this setting in php.ini will make Nextcloud run again" : "Adjusting this setting in php.ini will allow Nextcloud to run",
    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 is at least required. Currently %s is installed.",
    "To fix this issue update your libxml2 version and restart your web server." : "To fix this issue update your libxml2 version and restart your web server.",
    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator.",
    "PHP modules have been installed, but they are still listed as missing?" : "PHP modules have been installed, but they are still listed as missing?",
    "Please ask your server administrator to restart the web server." : "Please ask your server administrator to restart the web server.",
    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Please change the permissions to 0770 so that the directory cannot be listed by other users.",
    "Ensure there is a file called \".ocdata\" in the root of the data directory." : "Ensure there is a file called \".ocdata\" in the root of the data directory.",
    "Could not obtain lock type %d on \"%s\"." : "Could not obtain lock type %d on \"%s\".",
    "Storage unauthorized. %s" : "Storage unauthorised. %s",
    "Storage incomplete configuration. %s" : "Storage incomplete configuration. %s",
    "Storage connection error. %s" : "Storage connection error. %s",
    "Storage is temporarily not available" : "Storage is temporarily not available",
    "Storage connection timeout. %s" : "Storage connection timeout. %s",
    "%s enter the database username and name." : "%s enter the database username and name.",
    "%s enter the database username." : "%s enter the database username.",
    "%s enter the database name." : "%s enter the database name.",
    "%s you may not use dots in the database name" : "%s you may not use dots in the database name",
    "Cannot write into \"config\" directory" : "Cannot write into \"config\" directory",
    "This can usually be fixed by giving the webserver write access to the config directory. See %s" : "This can usually be fixed by giving the webserver write access to the config directory. See %s",
    "Cannot write into \"apps\" directory" : "Cannot write into \"apps\" directory",
    "Cannot create \"data\" directory" : "Cannot create \"data\" directory",
    "This can usually be fixed by giving the webserver write access to the root directory. See %s" : "This can usually be fixed by giving the webserver write access to the root directory. See %s",
    "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s." : "Permissions can usually be fixed by giving the webserver write access to the root directory. See %s.",
    "Setting locale to %s failed" : "Setting locale to %s failed",
    "Please install one of these locales on your system and restart your webserver." : "Please install one of these locales on your system and restart your webserver.",
    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"",
    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini",
    "PostgreSQL >= 9 required" : "PostgreSQL >= 9 required",
    "Please upgrade your database version" : "Please upgrade your database version",
    "Your data directory is readable by other users" : "Your data directory is readable by other users",
    "Your data directory must be an absolute path" : "Your data directory must be an absolute path",
    "Check the value of \"datadirectory\" in your configuration" : "Check the value of \"datadirectory\" in your configuration",
    "Your data directory is invalid" : "Your data directory is invalid"
},
"nplurals=2; plural=(n != 1);");
